@@ -42,14 +42,14 @@ from pathlib import Path
 workpath = os.getcwd()
 bsepth = os.path.dirname(__file__) + '/'
 
-WeiRuanYaHei = bsepth + r'typeface/WeiRuanYaHei-1.ttf'
+NotoSansCJK = bsepth + r'typeface/NotoSansCJKsc-Regular.otf'
 NotoColorEmoji = bsepth + r'typeface/NotoColorEmoji.ttf'
 CODE2000 = bsepth + r'typeface/CODE2000.ttf'
 Unifont = bsepth + r'typeface/Unifont.ttf.ttf'
 
 
 rtime = []
-mfont = TTFont(WeiRuanYaHei)
+mfont = TTFont(NotoSansCJK)
 muniMap = mfont['cmap'].tables[0].ttFont.getBestCmap()
 efont = TTFont(NotoColorEmoji)
 euniMap = efont['cmap'].tables[0].ttFont.getBestCmap()
@@ -345,7 +345,7 @@ class DynamicPictureRendering:
         qr.make(fit=True)
         return qr.make_image()
 
-    def AoutLine(self, limt, text, size, color='#000000', fount=WeiRuanYaHei, x=15, y=0):
+    def AoutLine(self, limt, text, size, color='#000000', fount=NotoSansCJK, x=15, y=0):
         """非富文本样式计算"""
         START_X = x
         START_Y = y
@@ -473,7 +473,7 @@ class DynamicPictureRendering:
         main = Image.new("RGB", (cpx*3, cpx), "#FFFFFF")
         main.paste(HeadRender)
         # 写昵称
-        ttf_path = WeiRuanYaHei
+        ttf_path = NotoSansCJK
         nicknameFont = ImageFont.truetype(ttf_path, int(cpx/6))
         img_draw = ImageDraw.Draw(main)
         img_draw.text((cpx-8, int(cpx/2-30)), userinfo.uname,
@@ -497,7 +497,7 @@ class DynamicPictureRendering:
         Background='#ffffff',
         FountColor='#000000',
         HightLightFountColor="#168bce",
-        MainFontPath=WeiRuanYaHei,
+        MainFontPath=NotoSansCJK,
         EmojiFontPath=NotoColorEmoji
     ):
         """
@@ -625,18 +625,18 @@ class DynamicPictureRendering:
 
             if NGSS[count]['type'] == 2 and NGSS[count]['data']['control'] == 2:
                 data = {
-                    'type': 3, 'text': Text[:NGSS[count]['start']], "data": 'element/box.png'}
+                    'type': 3, 'text': Text[:NGSS[count]['start']], "data": bsepth + 'element/box.png'}
                 RenderList.append(data)
                 data = {'type': NGSS[count]['type'], 'text': Text[NGSS[count]
                                                                   ['start']+1:NGSS[count]['end']], "data": NGSS[count]['data']}
             elif NGSS[count]['type'] == 2 and NGSS[count]['data']['control'] == 3:
                 data = {
-                    'type': 3, 'text': Text[:NGSS[count]['start']], "data": 'element/tick.png'}
+                    'type': 3, 'text': Text[:NGSS[count]['start']], "data": bsepth + 'element/tick.png'}
                 RenderList.append(data)
                 data = {'type': NGSS[count]['type'], 'text': Text[NGSS[count]
                                                                   ['start']+1:NGSS[count]['end']], "data": NGSS[count]['data']}
             elif NGSS[count]['type'] == 2 and NGSS[count]['data']['control'] == 5:
-                data = {'type': 3, 'text': '', "data": 'element/link.png'}
+                data = {'type': 3, 'text': '', "data": bsepth + 'element/link.png'}
                 RenderList.append(data)
                 data = {'type': NGSS[count]['type'],
                         'text': '网页链接', "data": NGSS[count]['data']}
@@ -850,7 +850,7 @@ class DynamicPictureRendering:
         用来渲染功能块，如 视频封面 专栏投稿 相册图片等等
 
         """
-        ttf_path = WeiRuanYaHei
+        ttf_path = NotoSansCJK
         nicknameFont = ImageFont.truetype(ttf_path, 25)
         sFont = ImageFont.truetype(ttf_path, 20)
         # 投稿视频和直播
@@ -901,7 +901,7 @@ class DynamicPictureRendering:
             img_draw = ImageDraw.Draw(img)
             textcount, allwidth = (0, 0)
             for t in title:
-                wihdt = self.get_font_render_size(WeiRuanYaHei, 25, t)[0]
+                wihdt = self.get_font_render_size(NotoSansCJK, 25, t)[0]
                 textcount += 1
                 allwidth += wihdt
                 if allwidth > 675:
@@ -994,7 +994,7 @@ class DynamicPictureRendering:
             title = card.title
             # ISDO 计算标题文字高度
             titlestly = self.AoutLine(
-                675, title, 30, color='#000000', fount=WeiRuanYaHei)
+                675, title, 30, color='#000000', fount=NotoSansCJK)
             lasttitle = titlestly[len(titlestly)-1]['d'][1] + 30
             tasks = []
             i = 0
@@ -1025,7 +1025,7 @@ class DynamicPictureRendering:
             lastpic = fulren[len(fulren)-1][1][1] + w
             if summary != '':
                 summstly = self.AoutLine(
-                    675, summary, 25, color='#666666', fount=WeiRuanYaHei, y=lastpic+20)
+                    675, summary, 25, color='#666666', fount=NotoSansCJK, y=lastpic+20)
                 lastsumm = summstly[len(summstly)-1]['d'][1] + 30
             else:
                 lastsumm = lastpic
@@ -1066,7 +1066,7 @@ class DynamicPictureRendering:
 
         """
         if display.add_on_card_info:
-            ttf_path = WeiRuanYaHei
+            ttf_path = NotoSansCJK
             nicknameFont = ImageFont.truetype(ttf_path, 25)
             sFont = ImageFont.truetype(ttf_path, 20)
             type = display.add_on_card_info[0].add_on_card_show_type
@@ -1094,10 +1094,10 @@ class DynamicPictureRendering:
                 desc = desc_first+'   '+desc_second
                 img = Image.new("RGB", (700, 150), "#f4f5f7")
                 img_draw = ImageDraw.Draw(img)
-                nicknameFont = ImageFont.truetype(WeiRuanYaHei, 25)
+                nicknameFont = ImageFont.truetype(NotoSansCJK, 25)
                 img_draw.text((40, 35), title,
                               font=nicknameFont, fill="#000000")
-                nicknameFont = ImageFont.truetype(WeiRuanYaHei, 20)
+                nicknameFont = ImageFont.truetype(NotoSansCJK, 20)
                 img_draw.text((40, 90), desc, font=nicknameFont, fill="#999")
 
                 return img
@@ -1105,13 +1105,13 @@ class DynamicPictureRendering:
                 img = Image.new("RGB", (700, 170), "#FFFFFF")
                 img_draw = ImageDraw.Draw(img)
                 vote_card = display.add_on_card_info[0].vote_card
-                nicknameFont = ImageFont.truetype(WeiRuanYaHei, 25)
+                nicknameFont = ImageFont.truetype(NotoSansCJK, 25)
                 tick_b = Image.open(
                     bsepth + 'element/tick_B.png').resize((140, 140))
                 img.paste(tick_b)
                 img_draw.text(
                     (180, 30), vote_card['desc'], font=nicknameFont, fill="#000000")
-                nicknameFont = ImageFont.truetype(WeiRuanYaHei, 20)
+                nicknameFont = ImageFont.truetype(NotoSansCJK, 20)
                 img_draw.text(
                     (180, 80), f"{vote_card['join_num']}人参与", font=nicknameFont, fill="#999")
                 return img
@@ -1168,7 +1168,7 @@ class DynamicPictureRendering:
                 # 这里一般是番剧、电视剧、影视等等
                 name = card.apiSeasonInfo.title
             # 头部信息字体
-            MainFont = ImageFont.truetype(WeiRuanYaHei, 28)
+            MainFont = ImageFont.truetype(NotoSansCJK, 28)
             img_d.text((20, 10), name, font=MainFont, fill="#178bcf")
 
             # 利用预渲染信息和渲染返回结果进行渲染
